
=======
History
=======

1.1.1
-----
cleanup RST parsing

1.1.0
-----
better parsing for --help output (can parse basic rst)
made changes to support chained commands


1.0.2
-----
bug fixes

1.0.0
-----
python 3 only, concurrent futures and direct template scripts

0.2.9
-----
bugs and decorator type

0.2.8
-----
small bugs

0.2.7
-----
add @file parsing to split_str
ensure encoding with detached terminal for stdin (for testing)

0.2.6
-----
python 3 beta

0.2.3
-----
added @file parsing to parse_file_list each line handled as its own call to parse_file_list

0.2.2
-----
kwarg bug in read_all_data

0.2.1
-----
change main_decs to function with version arg

0.2.0
-----
kwarg_match debug option

0.1.9
-----
added followers kwarg to crossref_all

0.1.8
-----
bug fixes

0.1.6
-----
add release to version bump

0.1.5
-----
first release on pypi

0.1.4
-----
added read_data, read_all_data, and read_epw to easily parse data files

0.1.3
-----
added script_template and script_template2 for easy in directory coding

0.1.2
-----
wrote readme

0.1.0
-----
first stable release

0.0.1
-----
Initial setup of the directory

